@@ -1,6 +1,8 @@
 from magicgui import magicgui
 import pyclesperanto_prototype as cle
+from napari_tools_menu import register_function
 
+@register_function(menu="Utilities > Select GPU")
 @magicgui(Select_GPU={
         "choices": cle.available_device_names(),
     },call_button='Select')
@@ -17,4 +19,4 @@ def select_gpu():
     if len(cle.available_device_names()) > 1:
         gpu_selector.show()
 
-select_gpu.device = None
\ No newline at end of file
+select_gpu.device = None
